pub struct SplTokenAdditionalDataV2 {
pub decimals: u8,
pub interest_bearing_config: Option<(InterestBearingConfig, UnixTimestamp)>,
pub scaled_ui_amount_config: Option<(ScaledUiAmountConfig, UnixTimestamp)>,
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fields
decimals: u8This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
interest_bearing_config: Option<(InterestBearingConfig, UnixTimestamp)>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
scaled_ui_amount_config: Option<(ScaledUiAmountConfig, UnixTimestamp)>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Implementations
Sourceimpl SplTokenAdditionalDataV2
impl SplTokenAdditionalDataV2
pub fn with_decimals(decimals: u8) -> Self
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.