pub struct UiConfigKey {
pub pubkey: String,
pub signer: bool,
}๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Fields
pubkey: String๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.signer: bool๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Trait Implementations
Sourceimpl Debug for UiConfigKey
impl Debug for UiConfigKey
Sourceimpl<'de> Deserialize<'de> for UiConfigKey
impl<'de> Deserialize<'de> for UiConfigKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UiConfigKey
impl PartialEq for UiConfigKey
Sourceimpl Serialize for UiConfigKey
impl Serialize for UiConfigKey
impl Eq for UiConfigKey
impl StructuralPartialEq for UiConfigKey