pub enum UiNonceState {
Uninitialized,
Initialized(UiNonceData),
}๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Expand description
A duplicate representation of NonceState for pretty JSON serialization
Variants
Uninitialized
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Initialized(UiNonceData)
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Trait Implementations
Sourceimpl Debug for UiNonceState
impl Debug for UiNonceState
Sourceimpl<'de> Deserialize<'de> for UiNonceState
impl<'de> Deserialize<'de> for UiNonceState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UiNonceState
impl PartialEq for UiNonceState
Sourceimpl Serialize for UiNonceState
impl Serialize for UiNonceState
impl Eq for UiNonceState
impl StructuralPartialEq for UiNonceState