pub struct UiMeta {
pub rent_exempt_reserve: StringAmount,
pub authorized: UiAuthorized,
pub lockup: UiLockup,
}Fields
rent_exempt_reserve: StringAmount👎Deprecated since 4.1.0:
Stake account rent must be calculated via the Rent sysvar. This value will cease to be correct once lamports-per-byte is adjusted.
lockup: UiLockupTrait Implementations
Sourceimpl<'de> Deserialize<'de> for UiMeta
impl<'de> Deserialize<'de> for UiMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for UiMeta
impl StructuralPartialEq for UiMeta