pub struct UiSlotHashEntry {
pub slot: Slot,
pub hash: String,
}๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Fields
slot: Slot๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.hash: String๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Trait Implementations
Sourceimpl Debug for UiSlotHashEntry
impl Debug for UiSlotHashEntry
Sourceimpl<'de> Deserialize<'de> for UiSlotHashEntry
impl<'de> Deserialize<'de> for UiSlotHashEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UiSlotHashEntry
impl PartialEq for UiSlotHashEntry
Sourceimpl Serialize for UiSlotHashEntry
impl Serialize for UiSlotHashEntry
impl Eq for UiSlotHashEntry
impl StructuralPartialEq for UiSlotHashEntry