pub enum VoteAccountType {
Vote(UiVoteState),
}๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Expand description
A wrapper enum for consistency across programs
Variants
Vote(UiVoteState)
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Trait Implementations
Sourceimpl Debug for VoteAccountType
impl Debug for VoteAccountType
Sourceimpl<'de> Deserialize<'de> for VoteAccountType
impl<'de> Deserialize<'de> for VoteAccountType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for VoteAccountType
impl PartialEq for VoteAccountType
Sourceimpl Serialize for VoteAccountType
impl Serialize for VoteAccountType
impl Eq for VoteAccountType
impl StructuralPartialEq for VoteAccountType