pub struct ValidatorInfo {
pub info: String,
}๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Fields
info: String๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Trait Implementations
Sourceimpl Debug for ValidatorInfo
impl Debug for ValidatorInfo
Sourceimpl Default for ValidatorInfo
impl Default for ValidatorInfo
Sourcefn default() -> ValidatorInfo
fn default() -> ValidatorInfo
Returns the โdefault valueโ for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ValidatorInfo
impl<'de> Deserialize<'de> for ValidatorInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ValidatorInfo
impl PartialEq for ValidatorInfo
Sourceimpl Serialize for ValidatorInfo
impl Serialize for ValidatorInfo
impl Eq for ValidatorInfo
impl StructuralPartialEq for ValidatorInfo